/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2005 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StatelessBean.java,v 1.1 2005/12/19 17:02:37 benoitf Exp $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas.ejb3.examples.statelessbean;

import javax.ejb.AroundInvoke;
import javax.ejb.CallbackListener;
import javax.ejb.Interceptors;
import javax.ejb.InvocationContext;
import javax.ejb.Remote;
import javax.ejb.Stateless;

/**
 * Simple stateless bean.
 * @author Florent Benoit
 */
@Stateless
@Remote(StatelessRemote.class)
//@Interceptors({StatelessInterceptor.class})
//@CallbackListener(Statelesslistener.class)
public class StatelessBean implements StatelessRemote {

    /**
     * Hello world.
     */
    public void helloWorld() {
        System.out.println("Hello world !");
    }

    /**
     * Compute a + b.
     * @param a first int
     * @param b second int
     * @return a + b
     */
    public int add(final int a, final int b) {
        return a + b;
    }

    /**
     * Divide a by b.
     * @param a first int
     * @param b second int
     * @return a / b
     */
    public int div(final int a, final int b) {
        if (b == 0) {
            throw new IllegalArgumentException("cannot divide by 0");
        }
        return a / b;
    }

    /**
     * Trace method's time.
     * @param invocationContext contains attributes of invocation
     * @return method's invocation result
     * @throws Exception if invocation fails
     */
    @AroundInvoke
    public Object trace(final InvocationContext invocationContext) throws Exception {
        System.out.println("TraceInterceptor : method '" + invocationContext.getMethod().getName()
                + "'.");
        long startPeriod = System.nanoTime();
        try {
            return invocationContext.proceed();
        } finally {
            long elapsed = System.nanoTime() - startPeriod;
            System.out.println("TraceInterceptor : Elapsed time = " + elapsed + " ns");
        }
    }

}
